@@ -12,7 +12,7 @@
 #' the specified time range, set `arrival` to TRUE.
 #'
 #' Journeys are defined by a "from" and "to" stop_id, a departure, arrival and travel time.
-#' Note that the exact journeys (with each intermediate stop and route ids for example) is
+#' Note that exact journeys (with each intermediate stop and route ids for example) are
 #' _not_ returned.
 #'
 #' For most cases, `stop_times` needs to be filtered, as it should only contain trips
@@ -32,21 +32,15 @@
 #'                 reasonably close to each other.
 #' @param arrival If FALSE (default), all journeys _start_ from `stop_ids`. If
 #'                TRUE, all journeys _end_ at `stop_ids`.
-#' @param time_range Either a range in seconds or a vector containing the
-#'                   minimal and maximal departure time (i.e. earliest and
-#'                   latest possible journey departure time) as seconds or
-#'                   "HH:MM:SS" character.
+#' @param time_range Either a range in seconds or a vector containing the minimal and maximal 
+#'                   departure time (i.e. earliest and latest possible journey departure time) 
+#'                   as seconds or "HH:MM:SS" character. If `arrival` is TRUE, `time_range` 
+#'                   describes the time window when journeys should end at `stop_ids`.
 #' @param max_transfers Maximum number of transfers allowed, no limit (NULL) as default.
 #' @param keep One of c("all", "shortest", "earliest", "latest"). By default, `all` journeys
-#'             between stop_ids are returned. With `shortest` only the journey with shortest
-#'             travel time is returned. With `earliest` the journey arriving at a stop the
-#'             earliest is returned, `latest` works accordingly.
-#'
-#' All departures from `stop_ids` within
-#'                   the time range stop_id in
-#'                   `stop_ids`) within `time_range` are considered. If `arrival` is TRUE,
-#'                   all arrivals within `time_range` before the latest arrival time of
-#'                   stop_times are considered.
+#'             between stop_ids are returned. With `shortest` only the journey with the 
+#'             shortest travel time is returned. With `earliest` the journey arriving at a 
+#'             stop the earliest is returned, `latest` works accordingly.
 #'
 #' @return A data.table with journeys (departure, arrival and travel time) to/from all
 #'         stop_ids reachable by `stop_ids`.
@@ -56,7 +50,7 @@
 #' @import data.table
 #' @export
 #' @examples \donttest{
-#' nyc_path <- system.file("extdata", "google_transit_nyc_subway.zip", package = "tidytransit")
+#' nyc_path <- system.file("extdata", "nyc_subway.zip", package = "tidytransit")
 #' nyc <- read_gtfs(nyc_path)
 #'
 #' # you can use initial walk times to different stops in walking distance (arbitrary example values)
@@ -132,7 +126,7 @@ raptor = function(stop_times,
     }
   }
   if(is.null(keep) || !(keep %in% c("shortest", "earliest", "all", "latest"))) {
-    stop(paste0(keep, " is not a supported optimization type, use one of: all, shortest, earliest, latest"))
+    stop(keep, " is not a supported optimization type, use one of: all, shortest, earliest, latest")
   }
   if(is.null(max_transfers)) {
     max_transfers <- 999999
@@ -149,13 +143,13 @@ raptor = function(stop_times,
                              journey_departure_stop_id = from_stop_ids,
                              transfers = 0, travel_time = 0)
   initial_transfers = find_initial_transfers(initial_stops, transfers_dt, max_transfers, arrival)
-  # browser()
+
   # 3) run raptor ####
   rptr = raptor_core(initial_stops, initial_transfers, stop_times_dt, transfers_dt, max_transfers)
 
   # reverse-engineer initial transfers ####
   if(nrow(initial_transfers) > 0) {
-    rptr <- rbindlist(list(rptr, initial_transfers[,colnames(rptr), with = F])) # in case no departures happened on transferrable stops
+    rptr <- rbindlist(list(rptr, initial_transfers[,colnames(rptr), with = FALSE])) # in case no departures happened on transferrable stops
     rptr_no_transfers = rptr[initial_stops, on = "journey_departure_stop_id"]
     rptr_no_transfers[,`:=`(from_stop_id = journey_departure_stop_id, to_stop_id = journey_arrival_stop_id)]
 
@@ -175,9 +169,9 @@ raptor = function(stop_times,
   }
 
   final_cns = c("from_stop_id", "to_stop_id", "travel_time", "journey_departure_time", "journey_arrival_time", "transfers")
-  raptor_result = rbindlist(list(initial_stops[,final_cns, with = F],
-                                 rptr_no_transfers[,final_cns, with = F],
-                                 rptr_with_initial_transfers[,final_cns, with = F]))
+  raptor_result = rbindlist(list(initial_stops[,final_cns, with = FALSE],
+                                 rptr_no_transfers[,final_cns, with = FALSE],
+                                 rptr_with_initial_transfers[,final_cns, with = FALSE]))
   raptor_result[, transfers := as.integer(transfers)]
 
   # revert times and switch from<->to
@@ -212,10 +206,10 @@ raptor = function(stop_times,
   # combine journey_origins to same stops (different departures)
   raptor_result <- rbindlist(list(
     raptor_result[from_stop_id != to_stop_id,],
-    raptor_result[from_stop_id == to_stop_id][, .SD[1], by = c("from_stop_id", "to_stop_id")][,colnames(raptor_result), with = F]))
+    raptor_result[from_stop_id == to_stop_id][, .SD[1], by = c("from_stop_id", "to_stop_id")][,colnames(raptor_result), with = FALSE]))
 
   # 6) return result table ####
-  raptor_result <- raptor_result[, final_cns, with=F]
+  raptor_result <- raptor_result[, final_cns, with=FALSE]
   return(raptor_result)
 }
 
@@ -236,7 +230,7 @@ find_initial_transfers = function(initial_stops, transfers_dt, max_transfers, ar
     initial_transfers[, travel_time := journey_arrival_time-journey_departure_time]
   }
 
-  return(initial_transfers[,colnames(initial_stops), with = F])
+  return(initial_transfers[,colnames(initial_stops), with = FALSE])
 }
 
 raptor_core = function(initial_stops, initial_transfers, stop_times_dt, transfers_dt,
@@ -253,7 +247,7 @@ raptor_core = function(initial_stops, initial_transfers, stop_times_dt, transfer
 
   # setup tables
   departures_marked[, `:=`(journey_departure_time = departure_time_num, journey_arrival_time = departure_time_num, journey_departure_stop_id = to_stop_id, marked_departure_time_num = departure_time_num, transfers = 0, marked = TRUE)]
-  rptr = as.data.table(departures_marked[,rptr_colnames, with = F])
+  rptr = as.data.table(departures_marked[,rptr_colnames, with = FALSE])
   departures_marked <- departures_marked[, c("trip_id", "marked_departure_time_num", "journey_departure_stop_id", "journey_departure_time")]
 
   # raptor loop
@@ -297,7 +291,7 @@ raptor_core = function(initial_stops, initial_transfers, stop_times_dt, transfer
     arrival_candidates[,marked := TRUE]
     # renaming and use same columns as rptr
     arrival_candidates[, journey_arrival_time := arrival_time_num]
-    arrival_candidates <- arrival_candidates[, rptr_colnames, with = F]
+    arrival_candidates <- arrival_candidates[, rptr_colnames, with = FALSE]
 
     # Find all transfers for arrival candidates
     if(!is.null(transfers_dt) && k <= max_transfers) {
@@ -315,13 +309,13 @@ raptor_core = function(initial_stops, initial_transfers, stop_times_dt, transfer
       # arrival_time needs to be calculated
       transfer_candidates[,journey_arrival_time := (journey_arrival_time + min_transfer_time)]
       transfer_candidates[,transfers := k]
-      transfer_candidates <- transfer_candidates[, rptr_colnames, with = F]
+      transfer_candidates <- transfer_candidates[, rptr_colnames, with = FALSE]
 
       arrival_candidates <- rbindlist(list(arrival_candidates, transfer_candidates))
     }
 
     # Bind all candidates and table with the current best times
-    rptr <- rbindlist(list(rptr, arrival_candidates), use.names = F)
+    rptr <- rbindlist(list(rptr, arrival_candidates), use.names = FALSE)
 
     # Keep earliest arrival times for each stop. Sort by journey_arrival_time
     # and rank all arrivals for each stop_id and journey_departure_stop/time.
@@ -329,7 +323,7 @@ raptor_core = function(initial_stops, initial_transfers, stop_times_dt, transfer
     # with groups
     setorder(rptr, journey_arrival_time)
     rptr <- rptr[, .SD[1], by = c("to_stop_id", "journey_departure_stop_id", "journey_departure_time")]
-    rptr <- rptr[, rptr_colnames, with = F]
+    rptr <- rptr[, rptr_colnames, with = FALSE]
 
     # iteration is finished, the remaining marked stops have been improved
     k <- k+1
@@ -401,7 +395,7 @@ setup_time_window = function(time_range, arrival, stop_times) {
       if(!is.null(attributes(stop_times)$min_departure_time)) {
         min_departure_time = attributes(stop_times)$min_departure_time
       } else {
-        min_departure_time = as.numeric(min(stop_times$departure_time, na.rm = T))
+        min_departure_time = as.numeric(min(stop_times$departure_time, na.rm = TRUE))
       }
       max_departure_time = min_departure_time + time_range
       time_window = c(min_departure_time, max_departure_time)
@@ -409,7 +403,7 @@ setup_time_window = function(time_range, arrival, stop_times) {
       if(!is.null(attributes(stop_times)$max_arrival_time)) {
         min_departure_time = -attributes(stop_times)$max_arrival_time
       } else {
-        min_departure_time = -as.numeric(max(stop_times$arrival_time, na.rm = T))
+        min_departure_time = -as.numeric(max(stop_times$arrival_time, na.rm = TRUE))
       }
       max_departure_time = min_departure_time + time_range
       time_window = sort(abs(c(min_departure_time, max_departure_time)))
