@@ -1,54 +1,8 @@
-#' Convert time columns to hms::hms in feed
-#' 
-#' Overwrites character columns in stop_times (arrival_time, departure_time) and 
-#' frequencies (start_time, end_time) with times converted with [hms::hms()].
-#' 
-#' @param gtfs_obj gtfs feed (tidygtfs object)
-#' @return gtfs_obj with hms times columns for stop_times and frequencies
-#' 
-#' @importFrom hms new_hms
-convert_times_to_hms <- function(gtfs_obj) {
-  arrival_time_hms <- departure_time_hms <- start_time_hms <- end_time_hms <-  NULL
-  
-  # stop_times ####
-  if(feed_contains(gtfs_obj, "stop_times")) {
-    stopifnot(inherits(gtfs_obj$stop_times, "data.table"))
-    gtfs_obj$stop_times[, arrival_time := hhmmss_to_hms(arrival_time)]
-    gtfs_obj$stop_times[, departure_time := hhmmss_to_hms(departure_time)]
-  }
-  
-  # frequencies ####
-  if(feed_contains(gtfs_obj, "frequencies") && nrow(gtfs_obj$frequencies) > 0) {
-    stopifnot(inherits(gtfs_obj$frequencies, "data.table"))
-    gtfs_obj$frequencies[, start_time := hhmmss_to_hms(start_time)]
-    gtfs_obj$frequencies[, end_time := hhmmss_to_hms(end_time)]
-  }
-  
-  return(gtfs_obj)
-}
-
-convert_hms_to_char <- function(gtfs_obj) {
-  if(feed_contains(gtfs_obj, "stop_times")) {
-    stopifnot(inherits(gtfs_obj$stop_times, "data.table"))
-    gtfs_obj$stop_times[, arrival_time := hms_to_hhmmss(arrival_time)]
-    gtfs_obj$stop_times[, departure_time := hms_to_hhmmss(departure_time)]
-  }
-  
-  if(feed_contains(gtfs_obj, "frequencies") && nrow(gtfs_obj$frequencies) > 0) {
-    stopifnot(inherits(gtfs_obj$frequencies, "data.table"))
-    gtfs_obj$frequencies[, start_time := hms_to_hhmmss(start_time)]
-    gtfs_obj$frequencies[, end_time := hms_to_hhmmss(end_time)]
-  }
-  
-  gtfs_obj
-}
-
-# string conversion functions ####
-
-#' convert a vector of time strings
+#' Convert "HH:MM:SS" time strings to hms values
 #' empty strings are converted to NA
 #' @param time_strings char vector ("HH:MM:SS")
-hhmmss_to_hms = function(time_strings) {
+#' @keywords internal
+hhmmss_to_hms <- function(time_strings) {
   if(inherits(time_strings, "hms")) { return(time_strings) }
   empty_strings = nchar(time_strings) == 0
   
@@ -63,8 +17,10 @@ hhmmss_to_hms = function(time_strings) {
   return(hms::new_hms(time_seconds))
 }
 
-#' Function to convert "HH:MM:SS" time strings to seconds.
-#' @param hhmmss_str string
+#' Convert "HH:MM:SS" time strings to seconds (numeric)
+#' empty strings are converted to NA
+#' @param hhmmss_str char vector ("HH:MM:SS")
+#' @keywords internal
 hhmmss_to_seconds <- function(hhmmss_str) {
   as.numeric(substr(hhmmss_str, 0, 2)) * 3600 +
     as.numeric(substr(hhmmss_str, 4, 5)) * 60 +
@@ -74,6 +30,7 @@ hhmmss_to_seconds <- function(hhmmss_str) {
 #' Fallback function to convert strings like 5:02:11
 #' 10x slower than [hhmmss_to_seconds()], empty strings are converted to NA
 #' @param hhmmss_str string
+#' @keywords internal
 hhmmss_to_sec_split <- function(hhmmss_str) {
   seconds = sapply(strsplit(hhmmss_str, ":"), function(Y) {
     sum(as.numeric(Y) * c(3600, 60, 1))
@@ -99,11 +56,12 @@ replace_NA_times = function(stop_times) {
 # interpolate stop_times ####
 
 #' Interpolate missing stop_times linearly
-#' Uses shape_dist_traveled if available
+#' 
 #' @param x tidygtfs object or stop_times table
-#' @param use_shape_dist if available, use shape_dist_traveled column for time
-#'                       interpolation. If shape_dist_traveled is missing, times
-#'                       are interpolated equally between stops. 
+#' @param use_shape_dist If TRUE, use `shape_dist_traveled` column from the shapes table for 
+#'                       time interpolation (if that column is available). If FALSE or 
+#'                       `shape_dist_traveled` is missing, times are interpolated equally 
+#'                       between stops. 
 #' @return tidygtfs or stop_times with interpolated arrival and departure times
 #' @examples
 #' \dontrun{
@@ -125,7 +83,7 @@ interpolate_stop_times = function(x, use_shape_dist = TRUE) {
     stoptimes = x
   }
   
-  stoptimes$....rowindex <- 1:nrow(stoptimes)
+  stoptimes$....rowindex <- seq_len(nrow(stoptimes))
   if(!use_shape_dist || !("shape_dist_traveled" %in% colnames(stoptimes))) {
     stoptimes$....shape_dist_traveled <- stoptimes$stop_sequence
   } else {
@@ -157,11 +115,11 @@ interpolate_stop_times = function(x, use_shape_dist = TRUE) {
 }
 
 approx_NA = function(values, x = NULL) {
-  if(!any(is.na(values))) {
+  if(!anyNA(values)) {
     return(values)
   }
   if(is.null(x)) {
-    x <- 1:length(values) 
+    x <- seq_len(length(values))
   }
   
   values_approx = stats::approx(x, values, x[is.na(values)], ties = "ordered")$y
