@@ -3,7 +3,7 @@ create_empty_gtfs_obj <- function() {
   gtfsio::new_gtfs(g)
 }
 
-test_that("convert_times_to_hms() works with valid data", {
+test_that("convert_char_to_hms() works with valid data", {
   gtest <- create_empty_gtfs_obj()
   gtest$stop_times <- data.table::data.table(
     arrival_time = c("08:00:00", "14:00:00", "26:10:00"),
@@ -13,7 +13,7 @@ test_that("convert_times_to_hms() works with valid data", {
     end_time = c("12:00:00")
   )
 
-  gtest <- convert_times_to_hms(gtest)
+  gtest <- convert_char_to_hms(gtest)
   
   expect_s3_class(gtest$stop_times$arrival_time, "hms")
   expect_s3_class(gtest$stop_times$departure_time, "hms")
@@ -107,9 +107,9 @@ test_that("set_dates_services() works with additions and exceptions", {
 
 test_that("parse dates", {
   x = "20180429"
-  y = parse_gtfsio_date(x)
+  y = .parse_gtfsio_date(x)
   expect_s3_class(y, "Date")
-  z = date_as_gtfsio_char(y)
+  z = .date_as_gtfsio_char(y)
   expect_equal(x, z)
 })
 
@@ -150,8 +150,8 @@ test_that("interpolate stop_times", {
   
   gtfs_duke2 = interpolate_stop_times(gtfs_duke)
   expect_equal(class(gtfs_duke2$stop_times), class(gtfs_duke$stop_times))
-  expect_false(any(is.na(gtfs_duke2$stop_times$arrival_time)))
-  expect_false(any(is.na(gtfs_duke2$stop_times$departure_time)))
+  expect_false(anyNA(gtfs_duke2$stop_times$arrival_time))
+  expect_false(anyNA(gtfs_duke2$stop_times$departure_time))
 })
 
 test_that("approx_NA", {
